@@ -26,9 +26,9 @@ class WindowsBridge(DatabaseMixin, Bridge):
         return self.windows_driver.validate(active_window, value)
 
     @traceback
-    def list_windows(self, exclude_title=None) -> OpenWindows:
+    def list_windows(self, exclude_titles=None) -> OpenWindows:
         self.logger.info("List available windows")
-        return self.windows_driver.list_windows(exclude_title)
+        return self.windows_driver.list_windows(exclude_titles)
 
     @traceback
     def focus(self, active_window: str, value: str) -> None:
